class WindowNavigation:
    def __init__(self, current_url = "/") -> None: ...
    def setdefault(self, url: str) -> None: ... 
    @property
    def homepage(self) -> str | None: ...
    @property
    def previous(self) -> str | None: ...
    @property
    def location(self) -> str | None: ...
    @location.setter
    def location(self, new_url: str) -> None: ...